==> foundry_platform_sdk-0.46.0.tar.gz: foundry_platform_sdk-0.46.0/foundry/v2/ontologies/models/_property_v2.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Optional
from typing import cast

import pydantic

from foundry.v2.core.models._display_name import DisplayName
from foundry.v2.ontologies.models._object_property_type import ObjectPropertyType
from foundry.v2.ontologies.models._property_type_rid import PropertyTypeRid
from foundry.v2.ontologies.models._property_type_status import PropertyTypeStatus
from foundry.v2.ontologies.models._property_type_visibility import PropertyTypeVisibility  # NOQA
from foundry.v2.ontologies.models._property_v2_dict import PropertyV2Dict


class PropertyV2(pydantic.BaseModel):
    """Details about some property of an object."""

    description: Optional[pydantic.StrictStr] = None

    display_name: Optional[DisplayName] = pydantic.Field(alias="displayName", default=None)

    data_type: ObjectPropertyType = pydantic.Field(alias="dataType")

    rid: PropertyTypeRid

    status: Optional[PropertyTypeStatus] = None

    visibility: Optional[PropertyTypeVisibility] = None

    model_config = {"extra": "allow"}

    def to_dict(self) -> PropertyV2Dict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(PropertyV2Dict, self.model_dump(by_alias=True, exclude_unset=True))

==> foundry_platform_sdk-0.66.0.tar.gz: foundry_platform_sdk-0.66.0/foundry/v2/ontologies/models/_property_v2.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Optional
from typing import cast

import pydantic

from foundry.v2.core.models._display_name import DisplayName
from foundry.v2.ontologies.models._object_property_type import ObjectPropertyType
from foundry.v2.ontologies.models._property_type_rid import PropertyTypeRid
from foundry.v2.ontologies.models._property_type_status import PropertyTypeStatus
from foundry.v2.ontologies.models._property_type_visibility import PropertyTypeVisibility  # NOQA
from foundry.v2.ontologies.models._property_v2_dict import PropertyV2Dict


class PropertyV2(pydantic.BaseModel):
    """Details about some property of an object."""

    description: Optional[str] = None

    display_name: Optional[DisplayName] = pydantic.Field(alias="displayName", default=None)

    data_type: ObjectPropertyType = pydantic.Field(alias="dataType")

    rid: PropertyTypeRid

    status: Optional[PropertyTypeStatus] = None

    visibility: Optional[PropertyTypeVisibility] = None

    model_config = {"extra": "allow"}

    def to_dict(self) -> PropertyV2Dict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(PropertyV2Dict, self.model_dump(by_alias=True, exclude_unset=True))
